@@ -55,32 +55,33 @@
 #pod
 #pod =head1 DESCRIPTION
 #pod
+#pod =head2 Purpose
+#pod
 #pod C<version> is an official Perl module for comparing versions. For example, (starting from Perl
 #pod 5.12.0) C<package> with a specified version:
 #pod
 #pod     package Assa v1.2.3;
 #pod
-#pod automatically assigns C<$VERSION> variable to a version object (i. e. an object of C<version>
-#pod class).
+#pod automatically assigns C<$VERSION> variable a version object (an object of C<version> class).
 #pod
-#pod C<Version::Dotted> is I<not> a replacement or alternative for C<version>. Modules should continue
-#pod to use C<version> implicitly (as shown in the example above) or explicitly:
+#pod C<Version::Dotted> is I<not> a replacement for C<version>. C<version> should be used to declare
+#pod package's version implicitly (as shown in the example above) or explicitly:
 #pod
 #pod     package Assa;
 #pod     use version 0.77; our $VERSION = version->declare( 'v1.2.3' );
 #pod
-#pod C<Version::Dotted> (or better its more specialized descendants: C<Version::Dotted::Semantic> and
-#pod C<Version::Dotted::Odd>) is intended for cases where you need to I<modify> version object. For
+#pod C<Version::Dotted> and its specialized descendants C<Version::Dotted::Semantic> and
+#pod C<Version::Dotted::Odd> are intended for cases where you need to I<modify> version object, for
 #pod example, in C<Dist::Zilla> C<AfterRelease> plugin:
 #pod
 #pod     sub after_release {
 #pod         my ( $self ) = @_;
-#pod         my $v = qv( $self->zilla->version );
-#pod         $v->bump( 'trial' );    # Version of the next release.
+#pod         my $v = qv( $self->zilla->version ); # Version of just-release distro.
+#pod         $v->bump( 'trial' );                 # Version of the next release.
 #pod         ...
 #pod     };
 #pod
-#pod or in C<ReleaseStatusProvider> plugin:
+#pod or detect version release status, for example, in C<ReleaseStatusProvider> plugin:
 #pod
 #pod     sub provide_release_status {
 #pod         my ( $self ) = @_;
@@ -88,45 +89,16 @@
 #pod         return $v->is_trial ? "testing" : "stable";
 #pod     };
 #pod
-#pod C<Version::Dotted> is very similar to C<Perl::Version>, but tries to avoid mess and confusing
-#pod created by supporting both decimal versions (C<1.003005>) and dotted versions (C<v1.3.5>).
-#pod C<Version::Dotted> does not support decimal versions intentionally to be simpler, cleaner and less
-#pod confusing.
-#pod
-#pod For the same purpose C<Version::Dotted> does I<not> use underscore (C<_>) to denote trial versions:
-#pod trial version C<v0.10.1_01> interpretation depends on C<version> version, it could be either
-#pod C<v0.10.1.1> or C<v0.10.101>.
-#pod
 #pod =head2 Dotted Version
 #pod
 #pod Dotted (aka dotted-decimal) version is a series of parts joined with dots, each part is a cardinal
 #pod (non-negative) integer. Every part (except the first) should be in range [0..999], the first part
 #pod can be bigger than 999.
 #pod
+#pod C<Version::Dotted> creates only dotted version objects.
+#pod
 #pod See also L<version::Internals/"Dotted-Decimal Versions">.
 #pod
-#pod =head2 Parent(s)
-#pod
-#pod C<Version::Dotted> is heavily influenced by C<Perl::Version>, but C<Version::Dotted> is I<not> a
-#pod subclass of C<Perl::Version>, C<Version::Dotted> I<is> a subclass of C<version>.
-#pod
-#pod The class narrows C<version> — C<Version::Dotted> creates only I<dotted> (aka dotted-decimal)
-#pod version objects, support for creating decimal versions is not provided. Support for "alpha"
-#pod versions is dropped too (subclasses provide support for "trial" versions instead).
-#pod
-#pod The class extends C<version> — C<Version::Dotted> objects are I<modifiable>.
-#pod
-#pod =head2 Warnings
-#pod
-#pod The class reports error by C<warnings::warnif>. It gives the caller flexibility: warning may be
-#pod either suppressed
-#pod
-#pod     no warnings 'Version::Dotted';
-#pod
-#pod or made fatal:
-#pod
-#pod     use warnings FATAL => 'Version::Dotted';
-#pod
 #pod =head2 Release Status
 #pod
 #pod Unfortunately, Perl terminology in this area in not well-defined and not consistently used:
@@ -163,7 +135,29 @@
 #pod generic term "trial": trial could be any of "alpha", "beta", "release candidate", "unstable", or
 #pod "testing".
 #pod
-#pod However, C<Version::Dotted> does not define C<is_trial> method but leaves this for subclasses.
+#pod C<Version::Dotted> does not define C<is_trial> method but its descendants do.
+#pod
+#pod =head2 Parent(s)
+#pod
+#pod C<Version::Dotted> is heavily influenced by C<Perl::Version>, but C<Version::Dotted> is I<not> a
+#pod subclass of C<Perl::Version>, C<Version::Dotted> I<is> a subclass of C<version>.
+#pod
+#pod The class narrows C<version> — C<Version::Dotted> creates only I<dotted> (aka dotted-decimal)
+#pod version objects, support for creating decimal versions is not provided. Support for "alpha"
+#pod versions is dropped too (subclasses provide support for "trial" versions instead).
+#pod
+#pod The class extends C<version> — C<Version::Dotted> objects are I<modifiable>.
+#pod
+#pod =head2 Error Reporting
+#pod
+#pod The class reports error by C<warnings::warnif>. It gives the caller flexibility: warning may be
+#pod either suppressed
+#pod
+#pod     no warnings 'Version::Dotted';
+#pod
+#pod or made fatal:
+#pod
+#pod     use warnings FATAL => 'Version::Dotted';
 #pod
 #pod =cut
 
@@ -175,7 +169,7 @@ use warnings::register;
 use version 0.77 qw{};
 
 # ABSTRACT: TODO
-our $VERSION = 'v0.0.0_05'; # TRIAL VERSION
+our $VERSION = 'v0.0.0_06'; # TRIAL VERSION
 
 use parent 'version';
 use overload (
@@ -219,39 +213,66 @@ sub _warn {
 #pod
 #pod Leading zeros in parts are insignificant:
 #pod
-#pod     Version::Dotted->new( v01.02.03 ) == Version::Dotted->new( v1.2.3 );
-#pod     Version::Dotted->new( 1.002 ) == Version::Dotted->new( v1.2 );
+#pod     qv( v01.02.03 ) == v1.2.3;
+#pod     qv( 1.002 )     == v1.2;
 #pod
 #pod However, Perl interprets numbers with leading zero as octal, so aware of:
 #pod
-#pod     Version::Dotted->new( 010 ) == v8;
-#pod     Version::Dotted->new( 010.011 ) == v89;         # oops
-#pod     Version::Dotted->new( 010.011.012 ) == v8910;   # ooops
+#pod     qv( 010     ) == v8;
+#pod     qv( 010.011 ) == v89;   # concatenation of two numbers 010 and 011
 #pod
 #pod To avoid surprises stick to using v-strings or strings:
 #pod
-#pod     Version::Dotted->new( v010 ) == Version::Dotted->new( v10 );
-#pod     Version::Dotted->new( v010.011 ) == Version::Dotted->new( v10.10 );
-#pod     Version::Dotted->new( '010.011' ) == Version::Dotted->new( v10.10 );
+#pod     qv( v010      ) == v10;
+#pod     qv( v010.011  ) == v10.10;
+#pod     qv( '010.011' ) == v10.10;
+#pod
+#pod =caveat Floating Point Numbers with Trailing Zeroes
+#pod
+#pod Perl ignores trailing zeros in floating point numbers:
+#pod
+#pod     1.200 == 1.2;
+#pod
+#pod so
+#pod
+#pod     qv( 1.200 ) == v1.2;    # not v1.200
+#pod
+#pod To avoid such surprises stick to using v-strings or strings:
+#pod
+#pod     qv( v1.200  ) == v1.200;
+#pod     qv( '1.200' ) == v1.200;
 #pod
 #pod =cut
 
 sub new {
     my ( $class, $arg ) = @_;
     my $v;
-    use DDP; p $arg;
-    defined $arg or $class->_warn( "Use of undefined value to construct version" );
-    if ( ref( $arg ) and $arg->isa( 'version' ) ) {
+    if ( eval { $arg->isa( 'version' ) } ) {
         $v = $class->declare( 0 );                      # Create a new version object.
         $v->{ version } = [ @{ $arg->{ version } } ];   # Copy version parts.
     } else {
-        $v = $class->declare( $arg // 0 );
+        if ( not defined $arg ) {
+            $class->_warn( "Use of undefined value to construct version" );
+            $arg = 'v0';
+        };
+        $v = $class->declare( $arg );
     };
     return $v->_norm();
 };
 
 # --------------------------------------------------------------------------------------------------
 
+# If $arg is a version object, return it as-is. Otherwise create a version object and return it.
+sub _obj {
+    my ( $self, $arg ) = @_;
+    if ( not eval { $arg->isa( 'version' ) } ) {
+        $arg = $self->new( $arg );
+    };
+    return $arg;
+};
+
+# --------------------------------------------------------------------------------------------------
+
 #pod =method C<part>
 #pod
 #pod Returns i-th part of the version.
@@ -342,17 +363,6 @@ sub _cmp {
 
 # --------------------------------------------------------------------------------------------------
 
-# If $arg is a version object, return it as-is. Otherwise create a version object and return it.
-sub _obj {
-    my ( $self, $arg ) = @_;
-    if ( not defined $arg or not $arg->isa( 'version' ) ) {
-        $arg = $self->new( $arg );
-    };
-    return $arg;
-};
-
-# --------------------------------------------------------------------------------------------------
-
 # Normalize version representation.
 sub _norm {
     my ( $self ) = @_;
@@ -478,16 +488,16 @@ sub numify {
 #   We have to redefine parents' import. Otherwise we will export `qv` into importer namespace by
 #   default. Explicit import of `qv` is a good idea, though.
 
-sub import {
+sub import {                                    ## no critic ( RequireArgUnpacking )
     my ( $class, @list ) = @_;
     my $pkg = caller();
     my %args = map( { $_ => 1 } @list );
     if ( delete( $args{ qv } ) ) {
         my $qv = $pkg . '::qv';
-        no strict 'refs';               ## no critic ( ProhibitNoStrict )
-        no warnings 'redefine';         ## no critic ( ProhibitNoWarnings )
-        $class->_warn( "Subroutine $qv redefined" ) if defined &$qv;
-        *$qv = sub {
+        no strict 'refs';                       ## no critic ( ProhibitNoStrict )
+        no warnings qw{ redefine prototype };   ## no critic ( ProhibitNoWarnings )
+        $class->_warn( "Subroutine '$qv' redefined" ) if defined &$qv;
+        *$qv = sub ($) {
             return $class->new( @_ );
         };
     };
@@ -572,12 +582,17 @@ sub import {
 #pod
 #pod =head1 WHY?
 #pod
-#pod I always used C<version> (a module recommended by C<Task::Kensho>) to compare versions:
+#pod In my C<AfterRelease> C<Dist::Zilla> plugin I need to bump current distribution version.
+#pod
+#pod I C<version> is an official Perl module (and also a module recommended by C<Task::Kensho>) to
+#pod compare versions:
 #pod
 #pod     if ( version->parse( $Module::VERSION ) < '0.10.1' ) {
 #pod         plan skip_all => "Module $Module::VERSION too old";
 #pod     };
 #pod
+#pod
+#pod
 #pod When I had a need to manipulate versions, I started to use C<Perl::Version> (another module
 #pod recommended by C<Task::Kensho>) because C<version> does not provide any method to modify version
 #pod object. I wanted to bump version of a distribution automatically after release, and
@@ -629,7 +644,7 @@ Version::Dotted - TODO
 
 =head1 VERSION
 
-Version v0.0.0_05, released on 2016-12-28 19:36 UTC.
+Version v0.0.0_06, released on 2016-12-30 00:11 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
@@ -673,32 +688,33 @@ are covered in the F<README>.
 
 =head1 DESCRIPTION
 
+=head2 Purpose
+
 C<version> is an official Perl module for comparing versions. For example, (starting from Perl
 5.12.0) C<package> with a specified version:
 
     package Assa v1.2.3;
 
-automatically assigns C<$VERSION> variable to a version object (i. e. an object of C<version>
-class).
+automatically assigns C<$VERSION> variable a version object (an object of C<version> class).
 
-C<Version::Dotted> is I<not> a replacement or alternative for C<version>. Modules should continue
-to use C<version> implicitly (as shown in the example above) or explicitly:
+C<Version::Dotted> is I<not> a replacement for C<version>. C<version> should be used to declare
+package's version implicitly (as shown in the example above) or explicitly:
 
     package Assa;
     use version 0.77; our $VERSION = version->declare( 'v1.2.3' );
 
-C<Version::Dotted> (or better its more specialized descendants: C<Version::Dotted::Semantic> and
-C<Version::Dotted::Odd>) is intended for cases where you need to I<modify> version object. For
+C<Version::Dotted> and its specialized descendants C<Version::Dotted::Semantic> and
+C<Version::Dotted::Odd> are intended for cases where you need to I<modify> version object, for
 example, in C<Dist::Zilla> C<AfterRelease> plugin:
 
     sub after_release {
         my ( $self ) = @_;
-        my $v = qv( $self->zilla->version );
-        $v->bump( 'trial' );    # Version of the next release.
+        my $v = qv( $self->zilla->version ); # Version of just-release distro.
+        $v->bump( 'trial' );                 # Version of the next release.
         ...
     };
 
-or in C<ReleaseStatusProvider> plugin:
+or detect version release status, for example, in C<ReleaseStatusProvider> plugin:
 
     sub provide_release_status {
         my ( $self ) = @_;
@@ -706,45 +722,16 @@ or in C<ReleaseStatusProvider> plugin:
         return $v->is_trial ? "testing" : "stable";
     };
 
-C<Version::Dotted> is very similar to C<Perl::Version>, but tries to avoid mess and confusing
-created by supporting both decimal versions (C<1.003005>) and dotted versions (C<v1.3.5>).
-C<Version::Dotted> does not support decimal versions intentionally to be simpler, cleaner and less
-confusing.
-
-For the same purpose C<Version::Dotted> does I<not> use underscore (C<_>) to denote trial versions:
-trial version C<v0.10.1_01> interpretation depends on C<version> version, it could be either
-C<v0.10.1.1> or C<v0.10.101>.
-
 =head2 Dotted Version
 
 Dotted (aka dotted-decimal) version is a series of parts joined with dots, each part is a cardinal
 (non-negative) integer. Every part (except the first) should be in range [0..999], the first part
 can be bigger than 999.
 
+C<Version::Dotted> creates only dotted version objects.
+
 See also L<version::Internals/"Dotted-Decimal Versions">.
 
-=head2 Parent(s)
-
-C<Version::Dotted> is heavily influenced by C<Perl::Version>, but C<Version::Dotted> is I<not> a
-subclass of C<Perl::Version>, C<Version::Dotted> I<is> a subclass of C<version>.
-
-The class narrows C<version> — C<Version::Dotted> creates only I<dotted> (aka dotted-decimal)
-version objects, support for creating decimal versions is not provided. Support for "alpha"
-versions is dropped too (subclasses provide support for "trial" versions instead).
-
-The class extends C<version> — C<Version::Dotted> objects are I<modifiable>.
-
-=head2 Warnings
-
-The class reports error by C<warnings::warnif>. It gives the caller flexibility: warning may be
-either suppressed
-
-    no warnings 'Version::Dotted';
-
-or made fatal:
-
-    use warnings FATAL => 'Version::Dotted';
-
 =head2 Release Status
 
 Unfortunately, Perl terminology in this area in not well-defined and not consistently used:
@@ -781,7 +768,29 @@ any support for "beta" and "release candidate". Thus, "alpha" term is dropped in
 generic term "trial": trial could be any of "alpha", "beta", "release candidate", "unstable", or
 "testing".
 
-However, C<Version::Dotted> does not define C<is_trial> method but leaves this for subclasses.
+C<Version::Dotted> does not define C<is_trial> method but its descendants do.
+
+=head2 Parent(s)
+
+C<Version::Dotted> is heavily influenced by C<Perl::Version>, but C<Version::Dotted> is I<not> a
+subclass of C<Perl::Version>, C<Version::Dotted> I<is> a subclass of C<version>.
+
+The class narrows C<version> — C<Version::Dotted> creates only I<dotted> (aka dotted-decimal)
+version objects, support for creating decimal versions is not provided. Support for "alpha"
+versions is dropped too (subclasses provide support for "trial" versions instead).
+
+The class extends C<version> — C<Version::Dotted> objects are I<modifiable>.
+
+=head2 Error Reporting
+
+The class reports error by C<warnings::warnif>. It gives the caller flexibility: warning may be
+either suppressed
+
+    no warnings 'Version::Dotted';
+
+or made fatal:
+
+    use warnings FATAL => 'Version::Dotted';
 
 =head1 EXPORT
 
@@ -920,24 +929,41 @@ The same as C<stringify>.
 
 Leading zeros in parts are insignificant:
 
-    Version::Dotted->new( v01.02.03 ) == Version::Dotted->new( v1.2.3 );
-    Version::Dotted->new( 1.002 ) == Version::Dotted->new( v1.2 );
+    qv( v01.02.03 ) == v1.2.3;
+    qv( 1.002 )     == v1.2;
 
 However, Perl interprets numbers with leading zero as octal, so aware of:
 
-    Version::Dotted->new( 010 ) == v8;
-    Version::Dotted->new( 010.011 ) == v89;         # oops
-    Version::Dotted->new( 010.011.012 ) == v8910;   # ooops
+    qv( 010     ) == v8;
+    qv( 010.011 ) == v89;   # concatenation of two numbers 010 and 011
 
 To avoid surprises stick to using v-strings or strings:
 
-    Version::Dotted->new( v010 ) == Version::Dotted->new( v10 );
-    Version::Dotted->new( v010.011 ) == Version::Dotted->new( v10.10 );
-    Version::Dotted->new( '010.011' ) == Version::Dotted->new( v10.10 );
+    qv( v010      ) == v10;
+    qv( v010.011  ) == v10.10;
+    qv( '010.011' ) == v10.10;
+
+=head2 Floating Point Numbers with Trailing Zeroes
+
+Perl ignores trailing zeros in floating point numbers:
+
+    1.200 == 1.2;
+
+so
+
+    qv( 1.200 ) == v1.2;    # not v1.200
+
+To avoid such surprises stick to using v-strings or strings:
+
+    qv( v1.200  ) == v1.200;
+    qv( '1.200' ) == v1.200;
 
 =head1 WHY?
 
-I always used C<version> (a module recommended by C<Task::Kensho>) to compare versions:
+In my C<AfterRelease> C<Dist::Zilla> plugin I need to bump current distribution version.
+
+I C<version> is an official Perl module (and also a module recommended by C<Task::Kensho>) to
+compare versions:
 
     if ( version->parse( $Module::VERSION ) < '0.10.1' ) {
         plan skip_all => "Module $Module::VERSION too old";
